# babel-plugin-majorajs

This is the Babel plugin required for [MajoraJS](https://github.com/SperaHealth/majora). Babel v6.0+ is required for this plugin.

Please follow the installation instructions in the [MajoraJS](https://github.com/SperaHealth/majora) documentation to get up and running.

## Why MajoraJS?

MajoraJS allows you to develop multiple white-label versions based on one main version of your React Native app. MajoraJS makes swapping app names, package ids, and moving assets like app icons easy. MajoraJS also lets you create custom components for each white-label version and import them only for that specific white-label version's build.

MajoraJS's required Babel plugin `babel-plugin-majorajs` allows you to determine at compile-time which components to import for your white-labeled app.

Example:

```jsx
import React from 'react';
import LogIn from '../components/LogIn';

export default class LogInContainer extends React.Component {
  render() {
    return <LogIn/>;
  }
}
```

Let's assume you have a `LogIn.js` file that acts as your login component for your app. You also have a white-label component file called `LogIn.whitelabel.js`. With `babel-plugin-majorajs`, your `import` statements are evaluated at compile time. If you use MajoraJS to build your app as a white-label version, Babel will change the `import` declaration to: `import LogIn from '../components/LogIn.whitelabel;` at compile time. This lets you set dynamic `import` statements that get evaluated at build time.

Without MajoraJS, you have code that probably looks like:

```jsx
import React from 'react';
import LogIn from '../components/LogIn';
import LogInWhiteLabel from '../components/LogIn.whitelabel';

export default class LogInContainer extends React.Component {
  render() {
    if (process.env.VERSION === 'WHITE_LABEL') {
      return <LogInWhiteLabel/>;
    }
    else {
      return <LogIn/>;
    }
  }
}
```

This is not optimal as you will need to either import all versions of the same component or write logic to determine which component to lazy-load at run-time. Both alternatives increase the size of your JavaScript bundle. With MajoraJS, you write one `import` statement every time.

## Installation

Download `babel-plugin-majorajs` by running `npm install --save-dev babel-plugin-majorajs`.

Add `babel-plugin-majorajs` to your `.babelrc` as a plugin:

```json
{
  "plugins": [ "babel-plugin-majorajs" ]
}
```

## Contributing

TODO
